##  Switching Between List and Grid View
You can switch to the list view by clicking the hamburger menu icon at the top right. The list view presents information in a detailed table format, making it easier to consume the information and perform bulk actions efficiently.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loioac78ecae31184145b827ea3508938923_LowRes.png)
Switching Between List and Grid View
